FlutterBuild class
Class which holds the necessary attributes to perform a build on various
platforms for the specified buildType.
Constructors
Properties
- appName → String
-
final
- appVersion → String
-
final
-
buildArgs
↔ List<
String> -
getter/setter pair
- buildVersion → Version
-
final
- flavor → String?
-
final
- flutterSdkPath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- installDeps → bool
-
final
- mainPath → String?
-
final
- releaseFolder → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
{required String buildCmd}) → Future< String?> -
Build the flutter binaries for the platform given in
buildCmd. -
copyWith(
{String? appName, String? appVersion, Version? buildVersion, List< String> ? buildArgs, String? mainPath, String? flavor, String? releaseFolder, bool? installDeps, String? flutterSdkPath}) → FlutterBuild -
getArtifactPath(
{required String platform, required String extension, CpuArchitecture? arch}) → String - Get the output path, where the artifact should be placed.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parseFlutterBuildResult(
String output) → String?