PlatformBuild class abstract
The platform where you want your app to be build for.
Constructors
- PlatformBuild({required BuildType buildType, required FlutterBuild flutterBuild})
-
const
Properties
- buildType → BuildType
-
final
- flutterBuild → FlutterBuild
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → Future< String?> - Release the app for the given platform release type. Returns the absolute output path.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited