MacOsPlatformBuild class

Build the app for MacOS.

Inheritance

Constructors

MacOsPlatformBuild({required BuildType buildType, required FlutterBuild flutterBuild})
const

Properties

buildType → BuildType
finalinherited
flutterBuild → FlutterBuild
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → Future<String?>
Build the artifact for macOS. It creates a .zip archive.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited