FlutterPublish class

Constructors

FlutterPublish({PublishStage? stage, bool? isDryRun})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDryRun → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stage → PublishStage?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited